@@ -1,6 +1,6 @@
 package Net::Stomp::MooseHelpers::CanConnect;
 {
-  $Net::Stomp::MooseHelpers::CanConnect::VERSION = '1.0';
+  $Net::Stomp::MooseHelpers::CanConnect::VERSION = '1.3.1';
 }
 {
   $Net::Stomp::MooseHelpers::CanConnect::DIST = 'Net-Stomp-MooseHelpers';
@@ -11,8 +11,7 @@ use Net::Stomp::MooseHelpers::Types qw(NetStompish
                                        ServerConfigList
                                        Headers
                                   );
-use MooseX::Types::Common::Numeric qw(PositiveInt);
-use MooseX::Types::Moose qw(CodeRef);
+use MooseX::Types::Moose qw(CodeRef Bool);
 use Try::Tiny;
 use namespace::autoclean;
 
@@ -26,6 +25,18 @@ has connection => (
 );
 
 
+has is_connected => (
+    traits => ['Bool'],
+    is => 'ro',
+    isa => Bool,
+    default => 0,
+    handles => {
+      _set_disconnected => 'unset',
+      _set_connected => 'set',
+    },
+);
+
+
 has connection_builder => (
     is => 'rw',
     isa => CodeRef,
@@ -83,20 +94,6 @@ sub current_server {
 }
 
 
-has tries_per_server => (
-    is => 'ro',
-    isa => PositiveInt,
-    default => 1,
-);
-
-
-has connect_retry_delay => (
-    is => 'ro',
-    isa => PositiveInt,
-    default => 15,
-);
-
-
 has connect_headers => (
     is => 'ro',
     isa => Headers,
@@ -109,6 +106,8 @@ sub _default_connect_headers { { } }
 sub connect {
     my ($self) = @_;
 
+    return if $self->has_connection and $self->is_connected;
+
     try {
         # the connection will be created by the lazy builder
         $self->connection; # needed to make sure that 'current_server'
@@ -118,7 +117,11 @@ sub connect {
             %{$self->connect_headers},
             %{$server->{connect_headers} || {}},
         );
-        $self->connection->connect(\%headers);
+        my $response = $self->connection->connect(\%headers);
+        if ($response->command eq 'ERROR') {
+            die $response->headers->{message} // 'some STOMP error';
+        }
+        $self->_set_connected;
     } catch {
         Net::Stomp::MooseHelpers::Exceptions::Stomp->throw({
             stomp_error => $_
@@ -129,6 +132,7 @@ sub connect {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -139,7 +143,7 @@ Net::Stomp::MooseHelpers::CanConnect - role for classes that connect via Net::St
 
 =head1 VERSION
 
-version 1.0
+version 1.3.1
 
 =head1 SYNOPSIS
 
@@ -186,6 +190,12 @@ The connection to the STOMP server. It's built using the
 L</connection_builder> (passing C<hostname> and C<port>), rotating
 servers via L</next_server>. It's usually a L<Net::Stomp> object.
 
+=head2 C<is_connected>
+
+True if a call to C</connect>
+succeded. L<Net::Stomp::MooseHelpers::ReconnectOnFailure> resets this
+when reconnecting; you should not care much about it.
+
 =head2 C<connection_builder>
 
 Coderef that, given a hashref of options, returns a connection. The
@@ -199,15 +209,6 @@ that is, an arrayref of hashrefs, each of which describes how to
 connect to a single server. Defaults to C<< [ { hostname =>
 'localhost', port => 61613 } ] >>.
 
-=head2 C<tries_per_server>
-
-How many times to try to connect to a server before trying the
-L</next_server>. Defaults to 1.
-
-=head2 C<connect_retry_delay>
-
-How many seconds to wait between connection attempts. Defaults to 15.
-
 =head2 C<connect_headers>
 
 Global setting for connection headers (passed to
@@ -233,6 +234,9 @@ L</connect_headers> and the per-server connect headers (from
 L</current_server>, slot C<connect_headers>). Throws a
 L<Net::Stomp::MooseHelpers::Exceptions::Stomp> if anything goes wrong.
 
+If the L</connection> attribute is set, and L</is_connected>, returns
+without doing anything.
+
 =head1 AUTHOR
 
 Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
@@ -245,4 +249,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
