@@ -1,15 +1,12 @@
 package Net::Stomp::MooseHelpers::TraceStomp;
 {
-  $Net::Stomp::MooseHelpers::TraceStomp::VERSION = '1.0';
+  $Net::Stomp::MooseHelpers::TraceStomp::VERSION = '1.3.1';
 }
 {
   $Net::Stomp::MooseHelpers::TraceStomp::DIST = 'Net-Stomp-MooseHelpers';
 }
 use Moose::Role;
-use MooseX::Types::Path::Class;
 use Moose::Util 'apply_all_roles';
-use Time::HiRes ();
-use File::Temp ();
 use namespace::autoclean;
 
 # ABSTRACT: role to wrap the Net::Stomp connection in tracing code
@@ -29,7 +26,7 @@ around '_build_connection' => sub {
 {
 package Net::Stomp::MooseHelpers::TraceStomp::ConnWrapper;
 {
-  $Net::Stomp::MooseHelpers::TraceStomp::ConnWrapper::VERSION = '1.0';
+  $Net::Stomp::MooseHelpers::TraceStomp::ConnWrapper::VERSION = '1.3.1';
 }
 {
   $Net::Stomp::MooseHelpers::TraceStomp::ConnWrapper::DIST = 'Net-Stomp-MooseHelpers';
@@ -64,6 +61,7 @@ around receive_frame => sub {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -74,7 +72,7 @@ Net::Stomp::MooseHelpers::TraceStomp - role to wrap the Net::Stomp connection in
 
 =head1 VERSION
 
-version 1.0
+version 1.3.1
 
 =head1 SYNOPSIS
 
@@ -122,4 +120,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
