@@ -1,6 +1,6 @@
 package Net::Stomp::MooseHelpers::TracerRole;
 {
-  $Net::Stomp::MooseHelpers::TracerRole::VERSION = '1.0';
+  $Net::Stomp::MooseHelpers::TracerRole::VERSION = '1.3.1';
 }
 {
   $Net::Stomp::MooseHelpers::TracerRole::DIST = 'Net-Stomp-MooseHelpers';
@@ -34,6 +34,7 @@ sub _dirname_from_destination {
     return '' unless defined $destination;
 
     my $ret = $destination;
+    $ret =~ s{^(queue|topic)/}{/$1/};
     $ret =~ s/\W+/_/g;
     return $ret;
 }
@@ -74,6 +75,7 @@ sub _save_frame {
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -84,7 +86,7 @@ Net::Stomp::MooseHelpers::TracerRole - role to dump Net::Stomp frames to disk
 
 =head1 VERSION
 
-version 1.0
+version 1.3.1
 
 =head1 DESCRIPTION
 
@@ -139,4 +141,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
